@@ -102,7 +102,7 @@ class MultiKernelManager(LoggingConfigurable):
         """A shim for backwards compatibility."""
         return self._pending_kernels
 
-    @default("context")  # type:ignore[misc]
+    @default("context")
     def _context_default(self) -> zmq.Context:
         self._created_context = True
         return zmq.Context()
@@ -250,7 +250,7 @@ class MultiKernelManager(LoggingConfigurable):
         """
         km, kernel_name, kernel_id = self.pre_start_kernel(kernel_name, kwargs)
         if not isinstance(km, KernelManager):
-            self.log.warning(
+            self.log.warning(  # type:ignore[unreachable]
                 "Kernel manager class ({km_class}) is not an instance of 'KernelManager'!".format(
                     km_class=self.kernel_manager_class.__class__
                 )
@@ -269,7 +269,7 @@ class MultiKernelManager(LoggingConfigurable):
             await task
             # raise an exception if one occurred during kernel startup.
             if km.ready.exception():
-                raise km.ready.exception()  # type: ignore
+                raise km.ready.exception()  # type: ignore[misc]
 
         return kernel_id
 
@@ -318,7 +318,7 @@ class MultiKernelManager(LoggingConfigurable):
             await fut
             # raise an exception if one occurred during kernel shutdown.
             if km.ready.exception():
-                raise km.ready.exception()  # type: ignore
+                raise km.ready.exception()  # type: ignore[misc]
 
     shutdown_kernel = run_sync(_async_shutdown_kernel)
 
@@ -602,7 +602,7 @@ class AsyncMultiKernelManager(MultiKernelManager):
 
     context = Instance("zmq.asyncio.Context")
 
-    @default("context")  # type:ignore[misc]
+    @default("context")
     def _context_default(self) -> zmq.asyncio.Context:
         self._created_context = True
         return zmq.asyncio.Context()
